=======================
The classification page
=======================

The `classification page <https://pesummary.github.io/GW190412/html/IMRPhenomPv3HM_IMRPhenomPv3HM_Classification.html>`_
provides the classification probabilities. We see a table showing the probabilities
for both the default and population prior (exportable to both `csv` and `json`)
and the `summaryclassification <../../cli/summaryclassification.html>`_ command
line which can be run to generate the same probabilities.

We also see several plots at the bottom to display these probabilities in a more
interactive manner. Both captions to explain the plot and command lines are
available by clicking on the button. 
